<p align="center">
  <img width="300" src="https://raw.githubusercontent.com/kraina-ai/overturemaestro/main/docs/assets/logos/overturemaestro_logo.png"><br/>
  <small>Generated using DALL·E 3 model with this prompt: Cute stylized conducting virtuoso using a paper map as music sheet. White background, minimalistic, vector graphics, clean background, encased in a circle. In navy and gold colours. Logo for a python library, should work well as small icon.</small>
</p>
